@@ -1664,8 +1664,12 @@ class LangServer:
             request = urllib.request.Request("https://pypi.org/pypi/fortls/json")
             with urllib.request.urlopen(request) as resp:
                 info = json.loads(resp.read().decode("utf-8"))
+                remote_v = version.parse(info["info"]["version"])
+                # Do not update from remote if it is a prerelease
+                if remote_v.is_prerelease:
+                    return False
                 # This is the only reliable way to compare version semantics
-                if version.parse(info["info"]["version"]) > v or test:
+                if remote_v > v or test:
                     self.post_message(
                         "A newer version of fortls is available for download", 3
                     )
@@ -1688,9 +1692,9 @@ class LangServer:
                         capture_output=True,
                     )
                     if result.stdout:
-                        log.info(result.stdout)
+                        log.info(result.stdout.decode("utf-8"))
                     if result.stderr:
-                        log.error(result.stderr)
+                        log.error(result.stderr.decode("utf-8"))
                     return True
         # No internet connection exceptions
         except (URLError, KeyError):
